from merge import csv_to_xlsx
from merge import multi_csv_to_single_csv
import os

def parse(args):
    src_path = args.get('--src-path', '.')
    xlsx_file = args.get('--xlsx-file', 'data.xlsx')
    sheet_name = args.get('--sheet-name', 'daily')
    return (src_path, xlsx_file, sheet_name)

def multiple_csv_to_single_xlsx(src_path, xlsx_file, sheet_name):
    dest_path = '.'
    output_name = 'digolds-dp.csv'
    csv_file = multi_csv_to_single_csv.multiple_csv_to_single_csv(src_path, dest_path, output_name)
    output = csv_to_xlsx.csv_to_xlsx(csv_file, xlsx_file, sheet_name)
    file_name = os.path.join(dest_path,output_name)
    if os.path.exists(file_name):
        os.remove(file_name)
    return output

if __name__ == "__main__":
    pass


from merge import csv_to_xlsx
from merge import multi_csv_to_single_csv
from merge import multi_csv_to_single_xlsx

sub_command_map = {
    'multi-csv2xlsx' : [multi_csv_to_single_xlsx.multiple_csv_to_single_xlsx, multi_csv_to_single_xlsx.parse],
    'csv2csv' : [multi_csv_to_single_csv.multiple_csv_to_single_csv, multi_csv_to_single_csv.parse],
    'csv2xlsx' : [csv_to_xlsx.csv_to_xlsx, csv_to_xlsx.parse]
}

def handle(args):
    sub_command = args[0]
    if sub_command in sub_command_map:
        command_set = sub_command_map[sub_command]
        handler = command_set[0]
        parser = command_set[1]
        ordered_args = parser(args[1])
        handler(*ordered_args)


from pandas.io.excel import ExcelWriter
import pandas

def parse(args):
    csv_file = args.get('--csv-file', 'data.csv')
    xlsx_file = args.get('--xlsx-file', 'data.xlsx')
    sheet_name = args.get('--sheet-name', 'daily')
    return (csv_file, xlsx_file, sheet_name)

def csv_to_xlsx(csv_file, xlsx_file, sheet_name):
    with ExcelWriter(xlsx_file) as ew:
        pandas.read_csv(csv_file).to_excel(ew, sheet_name=sheet_name, index=False)
        return xlsx_file

if __name__ == "__main__":
    csv_file = './tests/final_result.csv'
    xlsx_file = './tests/final_result.xlsx'
    sheet_name = 'daily'
    csv_to_xlsx(csv_file, xlsx_file, sheet_name)

# https://stackoverflow.com/questions/39099008/how-to-write-csv-files-into-xlsx-using-python-pandas
# https://www.codegrepper.com/code-examples/r/pandas+to+excel+no+index


import os, glob
import pandas as pd

def parse(args):
    src_path = args.get('--src-path', '.')
    dest_path = args.get('--dest-path', '.')
    output_name = args.get('--output-name', 'your-csv-file-name.csv')
    return (src_path, dest_path, output_name)

def multiple_csv_to_single_csv(src_path, dest_path, output_name):
    all_files = glob.glob(os.path.join(src_path, "*.csv"))
    df_from_each_file = (pd.read_csv(f, sep=',') for f in all_files)
    df_merged   = pd.concat(df_from_each_file, ignore_index=True)
    output_file = os.path.join(dest_path,output_name)
    df_merged.to_csv(output_file, index=False)
    return output_file

if __name__ == "__main__":
    src_path = './tests'
    dest_path = './tests'
    output_name = 'final_result.csv'
    multiple_csv_to_single_csv(src_path, dest_path, output_name)

# https://blog.softhints.com/how-to-merge-multiple-csv-files-with-python/
# https://stackoverflow.com/questions/20845213/how-to-avoid-python-pandas-creating-an-index-in-a-saved-csv


import setuptools

with open("README.MD", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="digolds-dp",
    version="0.0.2",
    author="SLZ",
    author_email="founders@digolds.cn",
    description="An easy-to-use data pipeline for data analysts",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/digolds/dp",
    entry_points={
        'console_scripts': [
            'dp = dp:run',
        ],
    },
    packages=setuptools.find_packages(),
    # https://python-packaging.readthedocs.io/en/latest/dependencies.html
    install_requires=[
        'pandas',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    include_package_data=True
)